@@ -1,18 +1,10 @@
-extern crate str_utils;
-
-#[macro_use]
-extern crate bencher;
-
-#[macro_use]
-extern crate manifest_dir_macros;
-
 use std::fs;
 
-use bencher::Bencher;
+use bencher::{benchmark_group, benchmark_main, Bencher};
 
 use str_utils::EqIgnoreAsciiCaseMultiple;
 
-const INPUT_PATH: &str = file_path!("benches/data/abcdefghijklmnop.txt");
+const INPUT_PATH: &str = manifest_dir_macros::file_path!("benches/data/abcdefghijklmnop.txt");
 
 fn eq_ignore_ascii_case_with_lowercase_multiple_naive_match(bencher: &mut Bencher) {
     let needle = fs::read_to_string(INPUT_PATH).unwrap();
